@@ -20,7 +20,7 @@ from annoworkcli.actual_working_time.list_actual_working_hours_daily import (
     filter_actual_daily_list,
 )
 from annoworkcli.actual_working_time.list_actual_working_time import ListActualWorkingTime
-from annoworkcli.annofab.utils import build_annofabapi_resource_and_login
+from annoworkcli.annofab.utils import build_annofabapi_resource
 from annoworkcli.common.annofab import TIMEZONE_OFFSET_HOURS, get_annofab_project_id_from_job, isoduration_to_hour
 from annoworkcli.common.cli import OutputFormat, build_annoworkapi, get_list_from_args
 from annoworkcli.common.utils import print_csv, print_json
@@ -432,10 +432,10 @@ def main(args):  # noqa: ANN001, ANN201
     main_obj = ListWorkingHoursWithAnnofab(
         annowork_service=build_annoworkapi(args),
         workspace_id=args.workspace_id,
-        annofab_service=build_annofabapi_resource_and_login(
+        annofab_service=build_annofabapi_resource(
             annofab_login_user_id=args.annofab_user_id,
             annofab_login_password=args.annofab_password,
-            mfa_code=args.annofab_mfa_code,
+            annofab_pat=args.annofab_pat,
         ),
         parallelism=args.parallelism,
     )
@@ -512,9 +512,9 @@ def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     )
 
     parser.add_argument("--parallelism", type=int, required=False, help="並列度。指定しない場合は、逐次的に処理します。")
-    parser.add_argument("--annofab_mfa_code", type=str, help="Annofabにログインする際のMFAコード")
     parser.add_argument("--annofab_user_id", type=str, help="Annofabにログインする際のユーザID")
     parser.add_argument("--annofab_password", type=str, help="Annofabにログインする際のパスワード")
+    parser.add_argument("--annofab_pat", type=str, help="Annofabにログインする際のパーソナルアクセストークン")
 
     parser.set_defaults(subcommand_func=main)
 
