@@ -6,7 +6,7 @@ from annofabapi.resource import Resource as AnnofabResource
 from annoworkapi.resource import Resource as AnnoworkResource
 
 import annoworkcli
-from annoworkcli.annofab.utils import build_annofabapi_resource_and_login
+from annoworkcli.annofab.utils import build_annofabapi_resource
 from annoworkcli.common.cli import build_annoworkapi
 
 logger = logging.getLogger(__name__)
@@ -55,10 +55,10 @@ def main(args):  # noqa: ANN001, ANN201
     main_obj = PutJobFromAnnofabProject(
         annowork_service=annowork_service,
         workspace_id=args.workspace_id,
-        annofab_service=build_annofabapi_resource_and_login(
+        annofab_service=build_annofabapi_resource(
             annofab_login_user_id=args.annofab_user_id,
             annofab_login_password=args.annofab_password,
-            mfa_code=args.annofab_mfa_code,
+            annofab_pat=args.annofab_pat,
         ),
     )
     main_obj.put_job_from_annofab_project(parent_job_id=args.parent_job_id, annofab_project_id=args.annofab_project_id, job_id=args.job_id)
@@ -96,9 +96,9 @@ def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
         required=False,
         help="追加するジョブのjob_idを指定してください。未指定の場合は ``--annofab_project_id`` の値と同じです。",
     )
-    parser.add_argument("--annofab_mfa_code", type=str, help="Annofabにログインする際のMFAコード")
     parser.add_argument("--annofab_user_id", type=str, help="Annofabにログインする際のユーザID")
     parser.add_argument("--annofab_password", type=str, help="Annofabにログインする際のパスワード")
+    parser.add_argument("--annofab_pat", type=str, help="Annofabにログインする際のパーソナルアクセストークン")
 
     parser.set_defaults(subcommand_func=main)
 
