@@ -171,7 +171,7 @@ def mask_credential_in_command(command: list[str]) -> list[str]:
         command: 実行するコマンドのリスト（変更されません）
     """
     tmp_command = copy.deepcopy(command)
-    for masked_option in ["--annofab_user_id", "--annofab_password", "--mfa_code"]:
+    for masked_option in ["--annofab_user_id", "--annofab_password"]:
         try:
             index = tmp_command.index(masked_option)
             tmp_command[index + 1] = "***"
@@ -225,15 +225,15 @@ def visualize_statistics(temp_dir: Path, args):  # noqa: ANN001, ANN201
     if args.output_dir is not None:
         command.extend(["--output_dir", str(args.output_dir)])
 
-    if args.annofab_mfa_code is not None:
-        command.extend(["--mfa_code", str(args.annofab_mfa_code)])
-
     if args.annofab_user_id is not None:
         command.extend(["--annofab_user_id", str(args.annofab_user_id)])
 
     if args.annofab_password is not None:
         command.extend(["--annofab_password", str(args.annofab_password)])
 
+    if args.annofab_pat is not None:
+        command.extend(["--annofab_pat", str(args.annofab_pat)])
+
     if args.annofabcli_options is not None:
         command.extend(args.annofabcli_options)
 
@@ -270,9 +270,9 @@ def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
 
     parser.add_argument("--temp_dir", type=Path, required=False, help="テンポラリディレクトリ")
 
-    parser.add_argument("--annofab_mfa_code", type=str, help="Annofabにログインする際のMFAコード")
     parser.add_argument("--annofab_user_id", type=str, help="Annofabにログインする際のユーザID")
     parser.add_argument("--annofab_password", type=str, help="Annofabにログインする際のパスワード")
+    parser.add_argument("--annofab_pat", type=str, help="Annofabにログインする際のパーソナルアクセストークン")
 
     # 残りの引数は `annofabcli statistics visualize`コマンドにそのまま渡す
     parser.add_argument(
