@@ -1,7 +1,6 @@
 """
 annofabに関するutil関係の関数
 """
-from __future__ import annotations
 
 from typing import Any, Optional
 
@@ -20,7 +19,7 @@ def get_annofab_project_id_from_job(job: dict[str, Any]) -> Optional[str]:
     return get_annofab_project_id_from_url(url)
 
 
-def isoduration_to_hour(duration) -> float:
+def isoduration_to_hour(duration) -> float:  # noqa: ANN001
     """
     ISO 8601 duration を 時間に変換する
     Args:
