@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import argparse
 import logging
 from typing import Any, Optional
@@ -14,11 +12,11 @@ logger = logging.getLogger(__name__)
 
 
 class DeleteExpectedWorkingTime:
-    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):
+    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):  # noqa: ANN204
         self.annowork_service = annowork_service
         self.workspace_id = workspace_id
 
-    def delete_expected_working_times(self, expected_working_times: list[dict[str, Any]]):
+    def delete_expected_working_times(self, expected_working_times: list[dict[str, Any]]):  # noqa: ANN201
         for expected in expected_working_times:
             self.annowork_service.api.delete_expected_working_time_by_workspace_member(
                 self.workspace_id,
@@ -27,9 +25,7 @@ class DeleteExpectedWorkingTime:
             )
 
     def get_expected_working_times(self, *, user_id: str, start_date: str, end_date: str) -> list[dict[str, Any]]:
-        workspace_members = self.annowork_service.api.get_workspace_members(
-            self.workspace_id, query_params={"includes_inactive_members": True}
-        )
+        workspace_members = self.annowork_service.api.get_workspace_members(self.workspace_id, query_params={"includes_inactive_members": True})
         member = more_itertools.first_true(workspace_members, pred=lambda e: e["user_id"] == user_id)
         if member is None:
             logger.warning(f"{user_id=} のユーザはワークスペースメンバに存在しませんでした。")
@@ -45,12 +41,10 @@ class DeleteExpectedWorkingTime:
             self.workspace_id, workspace_member_id=workspace_member_id, query_params=query_params
         )
 
-    def main(self, *, user_id: str, start_date: str, end_date: str):
-        expected_working_times = self.get_expected_working_times(
-            user_id=user_id, start_date=start_date, end_date=end_date
-        )
+    def main(self, *, user_id: str, start_date: str, end_date: str):  # noqa: ANN201
+        expected_working_times = self.get_expected_working_times(user_id=user_id, start_date=start_date, end_date=end_date)
         if len(expected_working_times) == 0:
-            logger.info(f"削除する予定稼働時間情報はありませんでした。")
+            logger.info("削除する予定稼働時間情報はありませんでした。")
             return
 
         yesno = prompt_yesno(
@@ -61,7 +55,7 @@ class DeleteExpectedWorkingTime:
             self.delete_expected_working_times(expected_working_times)
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
     DeleteExpectedWorkingTime(annowork_service=annowork_service, workspace_id=args.workspace_id).main(
         user_id=args.user_id,
@@ -70,7 +64,7 @@ def main(args):
     )
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
@@ -90,8 +84,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "delete"
     subcommand_help = "予定稼働時間を削除します。"
 
-    parser = annoworkcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help
-    )
+    parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help)
     parse_args(parser)
     return parser
