@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import argparse
 import logging
 from pathlib import Path
@@ -16,9 +14,7 @@ from annoworkcli.common.utils import print_csv, print_json
 logger = logging.getLogger(__name__)
 
 
-def filter_job_list_with_external_linkage_info_url(
-    job_list: list[dict[str, Any]], external_linkage_info_url_list: list[str]
-) -> list[dict[str, Any]]:
+def filter_job_list_with_external_linkage_info_url(job_list: list[dict[str, Any]], external_linkage_info_url_list: list[str]) -> list[dict[str, Any]]:
     result = []
     for job in job_list:
         url = job["external_linkage_info"].get("url")
@@ -34,7 +30,7 @@ def filter_job_list_with_external_linkage_info_url(
 
 
 class ListJob:
-    def __init__(
+    def __init__(  # noqa: ANN204
         self,
         annowork_service: AnnoworkResource,
         workspace_id: str,
@@ -56,9 +52,7 @@ class ListJob:
             job_list = [job for job in job_list if job["job_id"] in set(job_id_list)]
 
         if parent_job_id_list is not None:
-            job_list = [
-                job for job in job_list if get_parent_job_id_from_job_tree(job["job_tree"]) in set(parent_job_id_list)
-            ]
+            job_list = [job for job in job_list if get_parent_job_id_from_job_tree(job["job_tree"]) in set(parent_job_id_list)]
 
         if external_linkage_info_url_list is not None:
             job_list = filter_job_list_with_external_linkage_info_url(job_list, external_linkage_info_url_list)
@@ -78,7 +72,7 @@ class ListJob:
 
         return job_list
 
-    def main(
+    def main(  # noqa: ANN201
         self,
         output: Path,
         output_format: OutputFormat,
@@ -95,7 +89,7 @@ class ListJob:
             is_add_parent_job_info=is_add_parent_job_info,
         )
         if len(job_list) == 0:
-            logger.warning(f"ジョブ情報は0件なので、出力しません。")
+            logger.warning("ジョブ情報は0件なので、出力しません。")
             return
 
         logger.debug(f"{len(job_list)} 件のジョブ一覧を出力します。")
@@ -107,7 +101,7 @@ class ListJob:
             print_csv(df, output=output)
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
 
     job_id_list = get_list_from_args(args.job_id)
@@ -124,7 +118,7 @@ def main(args):
     )
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
