@@ -7,7 +7,7 @@ import annoworkcli.workspace.put_workspace
 from annoworkcli.common.cli import add_parser as add_root_parser
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     subparsers = parser.add_subparsers(dest="subcommand_name")
     annoworkcli.workspace.list_workspace.add_parser(subparsers)
     annoworkcli.workspace.put_workspace.add_parser(subparsers)
@@ -17,8 +17,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "workspace"
     subcommand_help = "ワークスペース関係のサブコマンド"
 
-    parser = add_root_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help, is_subcommand=False
-    )
+    parser = add_root_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help, is_subcommand=False)
     parse_args(parser)
     return parser
