@@ -1,8 +1,7 @@
-from __future__ import annotations
-
 import argparse
 import logging
-from typing import Any, Collection, Optional
+from collections.abc import Collection
+from typing import Any, Optional
 
 from annoworkapi.enums import Role
 from annoworkapi.resource import Resource as AnnoworkResource
@@ -14,7 +13,7 @@ logger = logging.getLogger(__name__)
 
 
 class ChangeWorkspaceMemberProperties:
-    def __init__(
+    def __init__(  # noqa: ANN204
         self,
         *,
         annowork_service: AnnoworkResource,
@@ -40,16 +39,12 @@ class ChangeWorkspaceMemberProperties:
             "last_updated_datetime": old_member["updated_datetime"],
         }
 
-        new_member = self.annowork_service.api.put_workspace_member(
-            self.workspace_id, workspace_member_id, request_body=request_body
-        )
+        new_member = self.annowork_service.api.put_workspace_member(self.workspace_id, workspace_member_id, request_body=request_body)
         logger.debug(f"{user_id=}, {workspace_member_id=}: ワークスペースメンバのロールを変更しました。 :: {new_member}")
         return True
 
-    def main(self, user_id_list: list[str], role: str):
-        workspace_members = self.annowork_service.api.get_workspace_members(
-            self.workspace_id, query_params={"includes_inactive_members": True}
-        )
+    def main(self, user_id_list: list[str], role: str):  # noqa: ANN201
+        workspace_members = self.annowork_service.api.get_workspace_members(self.workspace_id, query_params={"includes_inactive_members": True})
         member_dict: dict[str, dict[str, Any]] = {m["user_id"]: m for m in workspace_members}
         success_count = 0
         for user_id in user_id_list:
@@ -63,14 +58,10 @@ class ChangeWorkspaceMemberProperties:
                     logger.warning(f"{user_id=} のロールは '{role}' なので、ロールを変更する必要はありません。スキップします。")
                     continue
 
-                old_tags = self.annowork_service.api.get_workspace_member_tags(
-                    self.workspace_id, old_member["workspace_member_id"]
-                )
+                old_tags = self.annowork_service.api.get_workspace_member_tags(self.workspace_id, old_member["workspace_member_id"])
                 old_workspace_tag_ids = {e["workspace_tag_id"] for e in old_tags}
 
-                result = self.put_workspace_member(
-                    user_id, role=role, old_workspace_tag_ids=old_workspace_tag_ids, old_member=old_member
-                )
+                result = self.put_workspace_member(user_id, role=role, old_workspace_tag_ids=old_workspace_tag_ids, old_member=old_member)
                 if result:
                     success_count += 1
             except Exception as e:
@@ -80,7 +71,7 @@ class ChangeWorkspaceMemberProperties:
         logger.info(f"{success_count}/{len(user_id_list)} 件のユーザをワークスペースメンバに登録しました。")
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
     user_id_list = get_list_from_args(args.user_id)
     assert user_id_list is not None
@@ -90,7 +81,7 @@ def main(args):
     ).main(user_id_list=user_id_list, role=args.role)
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
@@ -123,8 +114,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "change"
     subcommand_help = "ワークスペースメンバの情報（ロールなど）を変更します。"
 
-    parser = annoworkcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help
-    )
+    parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help)
     parse_args(parser)
     return parser
