@@ -1,9 +1,8 @@
-from __future__ import annotations
-
 import argparse
 import logging
 import uuid
-from typing import Any, Collection, Optional
+from collections.abc import Collection
+from typing import Any, Optional
 
 from annoworkapi.enums import Role
 from annoworkapi.resource import Resource as AnnoworkResource
@@ -15,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 
 class PutWorkspaceMember:
-    def __init__(
+    def __init__(  # noqa: ANN204
         self,
         annowork_service: AnnoworkResource,
         workspace_id: str,
@@ -23,7 +22,7 @@ class PutWorkspaceMember:
         self.annowork_service = annowork_service
         self.workspace_id = workspace_id
 
-    def put_workspace_member(
+    def put_workspace_member(  # noqa: ANN201
         self,
         user_id: str,
         role: str,
@@ -55,16 +54,12 @@ class PutWorkspaceMember:
         if last_updated_datetime is not None:
             request_body["last_updated_datetime"] = last_updated_datetime
 
-        new_member = self.annowork_service.api.put_workspace_member(
-            self.workspace_id, workspace_member_id, request_body=request_body
-        )
+        new_member = self.annowork_service.api.put_workspace_member(self.workspace_id, workspace_member_id, request_body=request_body)
         logger.debug(f"{user_id=} :: ワークスペースメンバを追加しました。 :: username='{new_member['username']}', {workspace_member_id=}")
         return True
 
-    def main(self, user_id_list: list[str], role: str, workspace_tag_id_list: Optional[Collection[str]]):
-        workspace_members = self.annowork_service.api.get_workspace_members(
-            self.workspace_id, query_params={"includes_inactive_members": True}
-        )
+    def main(self, user_id_list: list[str], role: str, workspace_tag_id_list: Optional[Collection[str]]):  # noqa: ANN201
+        workspace_members = self.annowork_service.api.get_workspace_members(self.workspace_id, query_params={"includes_inactive_members": True})
         member_dict: dict[str, dict[str, Any]] = {m["user_id"]: m for m in workspace_members}
         success_count = 0
         for user_id in user_id_list:
@@ -84,7 +79,7 @@ class PutWorkspaceMember:
         logger.info(f"{success_count}/{len(user_id_list)} 件のユーザをワークスペースメンバに登録しました。")
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
     user_id_list = get_list_from_args(args.user_id)
     workspace_tag_id_list = get_list_from_args(args.workspace_tag_id)
@@ -95,7 +90,7 @@ def main(args):
     ).main(user_id_list=user_id_list, role=args.role, workspace_tag_id_list=workspace_tag_id_list)
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
@@ -137,8 +132,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "put"
     subcommand_help = "ワークスペースメンバを登録します。"
 
-    parser = annoworkcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help
-    )
+    parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help)
     parse_args(parser)
     return parser
